autowisp.processing_steps.tfa module — AutoWISP documentation

# autowisp.processing_steps.tfa module

## Class Inheritance Diagram

Apply TFA correction to lightcurves.

autowisp.processing_steps.tfa.main()

  Run the step from the command line.

autowisp.processing_steps.tfa.parse_command_line(*args)

  Parse the commandline optinos to a dictionary.

autowisp.processing_steps.tfa.tfa(lc_collection, start_status, configuration, mark_progress)

  Perform TFA on (a subset of the points in) the given lightucurves.